@@ -642,6 +642,11 @@ extern _X_EXPORT void
  */
 extern _X_EXPORT RRCrtcPtr RRCrtcCreate(ScreenPtr pScreen, void *devPrivate);
 
+/*
+ * Tests if findCrtc belongs to pScreen or slave screens
+ */
+extern _X_EXPORT Bool RRCrtcExists(ScreenPtr pScreen, RRCrtcPtr findCrtc);
+
 /*
  * Set the allowed rotations on a CRTC
  */
